package com.zanxiang.common.redis.configure;

import com.zanxiang.common.redis.utils.DistributedLockUtil;
import org.redisson.Redisson;
import org.redisson.api.RedissonClient;
import org.redisson.config.Config;
import org.springframework.boot.autoconfigure.data.redis.RedisProperties;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * <p>
 * Redisson配置
 * </p>
 *
 * @author zhengwangeng
 * @since 2020/10/19
 */
@Configuration
@EnableConfigurationProperties(RedisProperties.class)
public class RedissonConfig {

    @Bean
    public RedissonClient init(RedisProperties redisProperties) {
        Config config = new Config();
        // 使用单节点模式
        config.useSingleServer()
                // 节点地址 -》可以通过host:port的格式来指定节点地址。
                .setAddress("redis://" + redisProperties.getHost() + ":" + redisProperties.getPort())
//                .setAddress("redis://127.0.0.1:6379")
                // 连接池 默认 64
//                .setConnectionPoolSize()
                // 用于发布和订阅连接的连接池最大容量。连接池的连接数量自动弹性伸缩。 默认60
//                .setSubscriptionConnectionPoolSize(0)
                // 最小空闲连接数， 最小保持连接数（长连接）。长期保持一定数量的连接有利于提高瞬时写入反应速度。 默认32
//                .setConnectionMinimumIdleSize(0)
                // 默认1库
                .setDatabase(1)
                .setPassword(redisProperties.getPassword());
        RedissonClient redissonClient = Redisson.create(config);
        DistributedLockUtil.setRedissonClient(redissonClient);
        return redissonClient;
    }

}
