package com.zanxiang.manage.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.zanxiang.common.domain.ResultVo;
import com.zanxiang.manage.domain.params.*;
import com.zanxiang.manage.domain.vo.*;
import com.zanxiang.manage.service.GameService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author : lingfeng
 * @time : 2022-06-30
 * @description : 游戏管理接口
 */
@Api(tags = {"游戏管理接口"})
@RestController
@RequestMapping("/game")
@Slf4j
public class GameController {

    @Autowired
    private GameService gameService;

    @ApiOperation(value = "新增游戏")
    @PostMapping(value = "/add")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = GameListVO.class)})
    public ResultVo<Boolean> gameAdd(@Validated @RequestBody GameAddParam param) {
        return new ResultVo<>(gameService.gameAdd(param));
    }

    @ApiOperation(value = "游戏基本信息查询")
    @GetMapping(value = "/detail/info")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = GameInfoVO.class)})
    public ResultVo<GameInfoVO> getGameInfo(@RequestParam Long id) {
        return new ResultVo<>(gameService.getGameInfo(id));
    }

    @ApiOperation(value = "游戏基本信息更新")
    @PostMapping(value = "/detail/update")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = Boolean.class)})
    public ResultVo<Boolean> gameUpdate(@Validated @RequestBody GameUpdateParam param) {
        return new ResultVo<>(gameService.updateGameInfo(param));
    }

    @ApiOperation(value = "游戏对接参数获取展示")
    @GetMapping(value = "/dock/info")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = GameDockVO.class)})
    public ResultVo<GameDockVO> getGameDock(@RequestParam Long id) {
        return new ResultVo<>(gameService.getGameDock(id));
    }

    @ApiOperation(value = "游戏对接参数更新更新")
    @PostMapping(value = "/dock/update")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = Boolean.class)})
    public ResultVo<Boolean> gameDockUpdate(@Validated @RequestBody GameDockParam param) {
        return new ResultVo<>(gameService.gameDockUpdate(param));
    }

    @ApiOperation(value = "获取游戏关联信息")
    @GetMapping(value = "/relation/info")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = GameRelationVO.class)})
    public ResultVo<GameRelationVO> getGameRelation(@RequestParam Long id) {
        return new ResultVo<>(gameService.getGameRelation(id));
    }

    @ApiOperation(value = "关联游戏更新")
    @PostMapping(value = "/relation/update")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = Boolean.class)})
    public ResultVo<Boolean> relationGameUpdate(@Validated @RequestBody RelationGameUpdateParam param) {
        return new ResultVo<>(gameService.relationGameUpdate(param));
    }

    @ApiOperation(value = "导量游戏更新")
    @PostMapping(value = "/guide/update")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = GameListVO.class)})
    public ResultVo<Boolean> guideGameUpdateUpdate(@Validated @RequestBody GuideGameUpdateParam param) {
        return new ResultVo<>(gameService.guideGameUpdateUpdate(param));
    }

    @ApiOperation(value = "游戏列表查询")
    @PostMapping(value = "/list")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = GameListVO.class)})
    public ResultVo<IPage<GameListVO>> gameList(@Validated @RequestBody GameListParam param) {
        return new ResultVo<>(gameService.gameList(param));
    }

    @ApiOperation(value = "游戏选择列表查询")
    @GetMapping(value = "/choice/list")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = GameChoiceVO.class, responseContainer = "list")})
    public ResultVo<List<GameChoiceVO>> choiceList() {
        return new ResultVo<>(gameService.choiceList());
    }
}
