package com.zanxiang.sdk.common.listener;

import com.zanxiang.common.utils.StringUtils;
import com.zanxiang.sdk.domain.dto.PlatformOrderDTO;
import com.zanxiang.sdk.service.PerformOrderService;
import com.zanxiang.sdk.service.PlatformOrderService;
import lombok.extern.slf4j.Slf4j;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.event.EventListener;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.Objects;

/**
 * 订单支付完成事件监听
 *
 * @author xufeng
 * @date 2022/6/27 10:22
 */
@Configuration
@Component
@Slf4j
public class OrderPaySuccessListener {
    protected final Logger logger = LoggerFactory.getLogger(OrderPaySuccessListener.class);

    @Resource
    private PlatformOrderService platformOrderService;

    @Resource
    private PerformOrderService performOrderService;

    @EventListener
    @Async
    public void onApplicationEvent(OrderPaySuccessEvent event) {
        System.out.println("OrderPaySuccessListener success!");
        System.out.println(event.getOrderId());
        if (StringUtils.isEmpty(event.getOrderId())) {
            logger.error("缺少订单ID");
            return;
        }
        PlatformOrderDTO orderInfo = platformOrderService.info(event.getOrderId());
        if (Objects.isNull(orderInfo)) {
            logger.error("订单:{} 获取详情失败", event.getOrderId());
            return;
        }
        //用户充值统计更新
        performOrderService.userRechargeTotal(orderInfo);
        //检查是否为首充（账号首充）
        Boolean isFirstRecharge = performOrderService.checkIsFirstRecharge(orderInfo);
        //cp推送
        performOrderService.pushCp(orderInfo);
        //生成宽表数据
        performOrderService.createOrderComplete(orderInfo);


    }
}
